use v5.36;
use rlib '.';

use HexGrid;
use HexGrid::Pin;
use HexGrid::Dynamic;

use Carp;
use Data::Dumper;

use feature "signatures";
no warnings "experimental::signatures";

my $coords_regex = qr/^\s*(-?\d+)\s*,\s*(-?\d+)\s*$/;

my $grid = HexGrid->new(defaults => {
		style => { 'stroke-width' => 1, stroke => 'black' },
		show_coords => 1});

my $test_file = shift;
open(my $test_fh, $test_file);

my $mode = "";
while (my $line = <$test_fh>)
{
	if ($line =~ /== Regions/)
	{
		$mode = "Regions";
		next;
	}
	if ($line =~ /== Paths/)
	{
		$mode = "Paths";
		next;
	}
	if($mode eq "Regions")
	{
		my @fields = split '; ', $line;
		my $region = $grid->make_region(shift @fields);
		$region->{defaults}{colour} = shift @fields;
		foreach my $coords (@fields)
		{
			do { carp "Skipping bad spec: $coords"; next; } unless $coords =~ $coords_regex;
			$region->make_tile_at($1,$2);
		}
	}
	if($mode eq "Paths")
	{
		my @fields = split '; ', $line;
		my $name = shift @fields;
		my $colour = shift @fields;
		my $starts_from = shift @fields;
		my $ends_to = shift @fields;

		my @path_coords;
		foreach my $coords (@fields)
		{
			do { carp "Skipping bad spec: $coords"; next; } unless $coords =~ $coords_regex;
			push @path_coords, [$1,$2];
		}

		my $path = $grid->make_path_from($name, \@path_coords, colour => $colour, style => { 'stroke-width' => 5 });
		$path->{starts_from} = $HexGrid::DIR{$starts_from} if $starts_from;
		$path->{ends_to} = $HexGrid::DIR{$ends_to} if $ends_to;
	}
}

say $grid->render;
# say HexGrid::Dynamic::render_html($grid->render, {});
close $test_fh;
